@@ -3,22 +3,15 @@ import numpy as np
 import time
 import os
 
-OD_FRONT_CALIBRATION_FILENAME = "calibration_data_od_front.csv"
-OD_SIDE_CALIBRATION_FILENAME = "calibration_data_od_side.csv"
-OD_FRONT_OFF_CALIBRATION_FILENAME = "calibration_data_od_front_off.csv"
-OD_SIDE_OFF_CALIBRATION_FILENAME = "calibration_data_od_side_off.csv"
-OD_DATA_FILENAME = "OD_data.csv"
-
-
 class ODmeasurement:
     def __init__(self, pe, fit_calibration_functions=True):
         self.pe = pe
         self.dev = pe.dev
-        self.calibration_file_front = os.path.join(self.pe.name, OD_FRONT_CALIBRATION_FILENAME)
-        self.calibration_file_side = os.path.join(self.pe.name, OD_SIDE_CALIBRATION_FILENAME)
-        self.calibration_file_front_off = os.path.join(self.pe.name, OD_FRONT_OFF_CALIBRATION_FILENAME)
-        self.calibration_file_side_off = os.path.join(self.pe.name, OD_SIDE_OFF_CALIBRATION_FILENAME)
-        self.od_file = os.path.join(self.pe.name, OD_DATA_FILENAME)
+        self.calibration_file_front = os.path.join(self.pe.name, "calibration_data_od_front.csv")
+        self.calibration_file_side = os.path.join(self.pe.name, "calibration_data_od_side.csv")
+        self.calibration_file_front_off = os.path.join(self.pe.name, "calibration_data_od_front_off.csv")
+        self.calibration_file_side_off = os.path.join(self.pe.name, "calibration_data_od_side_off.csv")
+        self.od_file = os.path.join(self.pe.name, "log_OD.csv")
 
         self.calibration_functions = None
         if os.path.exists(self.calibration_file_front):
@@ -99,15 +92,19 @@ class ODmeasurement:
             calibration_functions += [function]
         self.calibration_functions = calibration_functions
 
-    def calculate_OD(self, FrontCurrent, tube):
+    def calculate_OD_from_calibration_function(self, FrontCurrent, tube):
         f = self.calibration_functions[tube]
         calculated_od = f(FrontCurrent)
         return calculated_od
 
-    def measure_OD(self, tube,log=True):
+    def measure_OD(self, tube,log=True,cycles=5, n_measurements=20, laserOnDelay=10, laserOffDelay=10,
+                        filter_errors=True, verbose=False):
         if callable(self.calibration_functions[tube]):
-            IFS, ISS, IFSoff, ISSoff = self.pe.Photodiodes.measure_current(tube)
-            measured_od = self.calculate_OD(IFS, tube)
+            IFS, ISS, IFSoff, ISSoff = self.pe.Photodiodes.measure_current(tube, cycles=cycles,
+                                                       n_measurements=n_measurements, laserOnDelay=laserOnDelay,
+                                                       laserOffDelay=laserOffDelay, filter_errors=filter_errors,
+                                                       verbose=verbose)
+            measured_od = self.calculate_OD_from_calibration_function(IFS, tube)
             if log:
                 self.log_od(tube, measured_od)
             return measured_od
@@ -117,11 +114,10 @@ class ODmeasurement:
     def log_od(self, tube, od_value):
         if not os.path.exists(self.od_file):
             with open(self.od_file, "w+") as f:
-                f.write("time, 0, 1, 2, 3, 4, 5, 6\n")
-        string = [" "] * 7
+                f.write("time,0,1,2,3,4,5,6\n")
+        string = [""] * 7
         string[tube] = str(od_value)
         string=",".join([time.ctime()] + string)+"\n"
-
         with open(self.od_file, "a") as f:
             f.write(string)
 
@@ -152,24 +148,21 @@ def fit_one_calibration_curve(current, OD):
 
     return current_to_OD
 
-def show_calibration_curves(df,functions):
+def show_calibration_curves(pe,show=True):
+    import matplotlib.pyplot as plt
+    df = pd.read_csv(os.path.join(pe.name, "calibration_data_od_front.csv"), index_col=0)
+    df.columns = df.columns.astype(int)
     for t in range(7):
         current = df[t].values
         OD = df.index
         x = np.log(current)
         y = np.log(OD + 1)
 
-        coefficients = np.polyfit(x, y, 4)
-        poly = np.poly1d(coefficients)
-
-        def current_to_OD(current):
-            x = np.log(current)
-            y = poly(x)
-            OD = np.exp(y) - 1
-            return OD
-
+        f = pe.OD_measurement.calibration_functions[t]
         x = np.linspace(10, 1700, 1690)
-        plt.plot(x, current_to_OD(x))
+        plt.plot(x, f(x))
         plt.plot(df[t].values, df.index, "ro")
-        plt.yscale("log")
-        plt.show()
+        # plt.yscale("log")
+        plt.grid()
+        if show:
+            plt.show()
\ No newline at end of file
